

[![PyPI](https://img.shields.io/pypi/v/aioinstagrapi)](https://pypi.org/project/aioinstagrapi/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/aioinstagrapi)
![Checked with mypy](https://img.shields.io/badge/mypy-checked-blue)


Features:

* Getting public data of user, posts, stories, highlights, followers and following users
* Getting public email and phone number, if the user specified them in his business profile
* Getting public data of post, story, album, Reels, IGTV data and the ability to download content
* Getting public data of hashtag and location data, as well as a list of posts for them
* Getting public data of all comments on a post and a list of users who liked it
* Management of [proxy servers](https://soax.com/), mobile devices and challenge resolver
* Login by username and password, sessionid and support 2FA
* Managing messages and threads for Direct and attach files
* Download and upload a Photo, Video, IGTV, Reels, Albums and Stories
* Work with Users, Posts, Comments, Insights, Collections, Location and Hashtag
* Insights by account, posts and stories
* Like, following, commenting, editing account (Bio) and much more else

# aioinstagrapi - Unofficial Async Instagram API for Python

Fast and effective asynchronous Instagram Private API wrapper (public+private requests and challenge resolver) without selenium. Use the most recent version of the API from Instagram, which was obtained using reverse-engineering with Charles Proxy and [Proxyman](https://proxyman.io/).

*Instagram API valid for **28 June 2023** (last reverse-engineering check)*

Support **Python >= 3.9**

